{% load static %}
<html>
<head>
    <meta charset="UTF-8">
    <meta name="viewport"
          content="width=device-width, user-scalable=no, initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <link rel="stylesheet" href="{% static 'dj_banner/css/index.css' %}">
    <title>Dj banner</title>
    <style>
        h1{
            text-align: center;
            padding: 20px;
            color: #17d250;
        }
    </style>
</head>
<body>

<h1 >Dj banner</h1>

<script>
    const DJ_BANNER_BACKEND_URL = 'http://127.0.0.1:8000'
</script>
<script src="{% static 'dj_banner/js/index.js' %}"></script>
</body>
</html>
