from setuptools import setup, find_packages

setup(
    name='dj_banner',
    version='1.0.0',
    description='slick Banner Ads for Django',
    long_description=open('README.md', encoding='utf8').read(),
    long_description_content_type='text/markdown',
    include_package_data=True,
    url='https://github.com/FZl47/dj_banner',
    author='FZl47',
    author_email='fzl8747@gmail.com',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
